# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.4.0] - 2025-05-02

### Added

- Providers now has a version picker, when one is selected, press `v`
- Loading indicators
- Fullscreen mode
- Content now reacts to page up, page down, home and end

## [0.3.0] - 2025-05-01

### Added

- Content is now scrollable with arrows
- Added keybindings for focusing Providers/Resources/Content respectively
- Search now has alternative keybind `/`
- Added version to the welcome screen headline

### Changed

- Search now works per window, separately for providers and resources
- Log is now toggle-able, off by default

## [0.2.0] - 2025-05-01

### Added

- Whatever was before :)
